# Generated by Django 5.2.4 on 2025-07-21 17:26

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("papercheck", "0002_alter_bankaccount_id_alter_check_id_alter_payee_id"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="check",
            name="payor_account_number",
        ),
        migrations.RemoveField(
            model_name="check",
            name="payor_city",
        ),
        migrations.RemoveField(
            model_name="check",
            name="payor_name",
        ),
        migrations.RemoveField(
            model_name="check",
            name="payor_phone",
        ),
        migrations.RemoveField(
            model_name="check",
            name="payor_street_1",
        ),
        migrations.RemoveField(
            model_name="check",
            name="payor_street_2",
        ),
        migrations.AddField(
            model_name="bankaccount",
            name="payor_city",
            field=models.CharField(blank=True, max_length=255),
        ),
        migrations.AddField(
            model_name="bankaccount",
            name="payor_name",
            field=models.CharField(blank=True, max_length=255),
        ),
        migrations.AddField(
            model_name="bankaccount",
            name="payor_phone",
            field=models.CharField(blank=True, max_length=50),
        ),
        migrations.AddField(
            model_name="bankaccount",
            name="payor_street_1",
            field=models.CharField(blank=True, max_length=255),
        ),
        migrations.AddField(
            model_name="bankaccount",
            name="payor_street_2",
            field=models.CharField(blank=True, max_length=255),
        ),
        migrations.AddField(
            model_name="payee",
            name="payor_account_number",
            field=models.CharField(blank=True, max_length=20),
        ),
    ]
