# Generated by Django 5.2.4 on 2025-07-21 17:38

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("papercheck", "0003_remove_check_payor_account_number_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="check",
            name="check_number",
            field=models.PositiveIntegerField(editable=False, unique=True),
        ),
    ]
