# Generated by Django 5.2.4 on 2025-07-21 17:47

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("papercheck", "0005_rename_name_bankaccount_formal_name_and_more"),
    ]

    operations = [
        migrations.RenameField(
            model_name="bankaccount",
            old_name="descriptive_name",
            new_name="account_nickname",
        ),
        migrations.RenameField(
            model_name="bankaccount",
            old_name="formal_name",
            new_name="institution_name",
        ),
    ]
