# Generated by Django 5.2.4 on 2025-07-21 18:41

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("papercheck", "0008_check_tags"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="category",
            options={"ordering": ["name"], "verbose_name_plural": "Categories"},
        ),
    ]
