# Generated by Django 5.2.4 on 2025-07-21 18:19

import taggit.managers
from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("papercheck", "0007_category_check_category"),
        (
            "taggit",
            "0006_rename_taggeditem_content_type_object_id_taggit_tagg_content_8fc721_idx",
        ),
    ]

    operations = [
        migrations.AddField(
            model_name="check",
            name="tags",
            field=taggit.managers.TaggableManager(
                blank=True,
                help_text="A comma-separated list of tags.",
                through="taggit.TaggedItem",
                to="taggit.Tag",
                verbose_name="Tags",
            ),
        ),
    ]
