# Generated by Django 5.2.4 on 2025-07-21 17:45

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("papercheck", "0004_alter_check_check_number"),
    ]

    operations = [
        migrations.RenameField(
            model_name="bankaccount",
            old_name="name",
            new_name="formal_name",
        ),
        migrations.AddField(
            model_name="bankaccount",
            name="descriptive_name",
            field=models.CharField(blank=True, max_length=255),
        ),
    ]
